@@ -102,10 +102,29 @@ RNGseq <- function(n, seed=NULL, ..., simplify=TRUE, version=2){
 	
 }
 
+# internal wrapper to handle the changes introduced in R 3.6
+RNGkind <- function(kind = NULL, normal.kind = NULL, sample.kind = NULL, ..., strict = TRUE){
+  if( !nargs() ) base::RNGkind()
+  else if( testRversion("<3.6.0") ){
+    if( !is.null(sample.kind) && strict )
+      stop(sprintf("Invalid RNGkind call: argument sample.kind is only supported in R >= 3.6.0 [current version: %s]", Rversion()))
+    base::RNGkind(kind = kind, normal.kind = normal.kind, ...)
+  }else base::RNGkind(kind = kind, normal.kind = normal.kind, sample.kind = sample.kind, ...)
+  
+}
+
+RNGkind_default <- function(){
+  RNGkind(kind = "default", normal.kind = "default", sample.kind = "default", strict = FALSE)
+  
+}
+  
 #' @describeIn RNGseq generates the -- next -- random seed used as the first seed in 
 #' the sequence generated by \code{\link{RNGseq}}. 
 #' 
-#' @param normal.kind Type of Normal random generator. See \code{\link{RNG}}.
+#' @param normal.kind Type of Normal random generator passed to [base::RNGkind]. See \code{\link{RNG}}.
+#' @param sample.kind Type of Discrete Uniform random generator passed to [base::RNGkind]. See \code{\link{RNG}}.
+#' Note that this argument is valid for R >= 3.6.0, and an error will be thrown if one tries to use it in previous
+#' versions of R.
 #' @param verbose logical to toggle verbose messages
 #' @param version version of the function to use, to reproduce old behaviours.
 #' Version 1 had a bug which made the generated stream sequences share most of their
@@ -134,7 +153,7 @@ RNGseq <- function(n, seed=NULL, ..., simplify=TRUE, version=2){
 #' identical(s, RNGseq_seed(1))
 #' \dontshow{ stopifnot(identical(s, RNGseq_seed(1))) }
 #'  
-RNGseq_seed <- function(seed=NULL, normal.kind=NULL, verbose=FALSE, version=2){
+RNGseq_seed <- function(seed=NULL, normal.kind = NULL, sample.kind = NULL, verbose=FALSE, version=2){
 	
 	# retrieve current seed
 	orng <- RNGseed()
@@ -154,7 +173,7 @@ RNGseq_seed <- function(seed=NULL, normal.kind=NULL, verbose=FALSE, version=2){
 			if( verbose ) message("# Generate RNGstream random seed from ", seed, " ... ", appendLF=FALSE)
 			if( version<2 || rkind_not_CMRG ){ # behaviour prior 1.4
 				set.seed(seed)
-				RNGkind(kind="L'Ecuyer-CMRG", normal.kind=normal.kind)
+				RNGkind(kind="L'Ecuyer-CMRG", normal.kind=normal.kind, sample.kind = sample.kind)
 			}else{ # fix seed after switching to CMRG: ensure result independence from the current RNG
 				set.seed(seed, kind="L'Ecuyer-CMRG", normal.kind=normal.kind)
 			}
@@ -162,7 +181,7 @@ RNGseq_seed <- function(seed=NULL, normal.kind=NULL, verbose=FALSE, version=2){
 		}
 		else if( length(seed) == 6L ){
 			if( verbose ) message("# Directly use 6-long seed: ",  paste(seed, collapse=', '), " ... ", appendLF=FALSE)
-			RNGkind("L'Ecuyer-CMRG", normal.kind=normal.kind)
+			RNGkind("L'Ecuyer-CMRG", normal.kind=normal.kind, sample.kind = sample.kind)
 			s <- RNGseed()
 			s[2:7] <- as.integer(seed)
 			RNGseed(s)
@@ -187,7 +206,7 @@ RNGseq_seed <- function(seed=NULL, normal.kind=NULL, verbose=FALSE, version=2){
 			orng <- orng1
 			
 			if( verbose ) message("# Generate random RNGstream seed: ", appendLF=FALSE)
-			RNGkind(kind="L'Ecuyer", normal.kind=normal.kind)
+			RNGkind(kind="L'Ecuyer", normal.kind=normal.kind, sample.kind = sample.kind)
 			if( verbose ) message("OK")
 		}else{ # seed with next RNG stream
 			if( version < 2 ){
@@ -197,7 +216,7 @@ RNGseq_seed <- function(seed=NULL, normal.kind=NULL, verbose=FALSE, version=2){
 				RNGseed(s)	
 			}else{
 				# only change normal kind if necessary and use current stream state
-				if( !is.null(normal.kind) ) RNGkind(normal.kind=normal.kind)
+				if( !is.null(normal.kind) || !is.null(sample.kind) ) RNGkind(normal.kind=normal.kind, sample.kind = sample.kind)
 				if( verbose ) message("# Use current active RNG stream: ", .collapse(RNGseed()[2:7]))
 			}
 		}
